@@ -346,6 +346,8 @@
    ;; fixed-type-specifier => "unsigned" "char"
    (lambda ($2 $1 . $rest)
      '(fixed-type "unsigned char"))
+   ;; fixed-type-specifier => "__int128"
+   (lambda ($1 . $rest) '(fixed-type "__int128"))
    ;; float-type-specifier => "float"
    (lambda ($1 . $rest) '(float-type "float"))
    ;; float-type-specifier => "double"
